@@ -602,7 +602,7 @@ gs_screen_next(gs_screen_enum * penum, double value)
     if (value < -1.0 || value > 1.0)
         return_error(gs_error_rangecheck);
     sample = (ht_sample_t) ((value + 1) * max_ht_sample);
-#if defined(DEBUG) && !defined(GS_THREADSAFE)
+#if defined(DEBUG)
     if (gs_debug_c('H')) {
         gs_point pt;
 
@@ -627,6 +627,7 @@ gs_screen_install(gs_screen_enum * penum)
     dev_ht.rc.memory = penum->halftone.rc.memory;
     dev_ht.order = penum->order;
     dev_ht.components = 0;
+    penum->halftone.objtype = HT_OBJTYPE_DEFAULT;
     if ((code = gx_ht_install(penum->pgs, &penum->halftone, &dev_ht)) < 0)
         gx_device_halftone_release(&dev_ht, dev_ht.rc.memory);
     return code;
